pub struct Suggestion {
pub word: String,
pub edit_distance: u8,
pub soundex_match: bool,
pub freq_score: u32,
}Expand description
A spelling suggestion returned by SpellChecker::suggestions.
Suggestions are sorted by:
soundex_matchdescending — phonetically similar words firstedit_distanceascending — closer edits firstfreq_scoredescending — more common words first
Fields
word: StringCandidate word from the built-in dictionary.
edit_distance: u8Levenshtein edit distance between the input and this candidate.
soundex_match: booltrue if the lk82 phonetic codes of the input and candidate match.
freq_score: u32TNC frequency score; 0 if the word is not in the frequency table.