Suggestion

Struct Suggestion 

pub struct Suggestion {
    pub word: String,
    pub edit_distance: u8,
    pub soundex_match: bool,
    pub freq_score: u32,
}
A spelling suggestion returned by SpellChecker::suggestions.

Suggestions are sorted by:

  1. soundex_match descending — phonetically similar words first
  2. edit_distance ascending — closer edits first
  3. freq_score descending — more common words first

Fields

word: String

Candidate word from the built-in dictionary.

edit_distance: u8

Levenshtein edit distance between the input and this candidate.

soundex_match: bool

true if the lk82 phonetic codes of the input and candidate match.

freq_score: u32

TNC frequency score; 0 if the word is not in the frequency table.